/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import * as tests from "@gnu-taler/web-util/testing";
import {
  CasesUI as TestedComponent,
} from "./Cases.js";
import { AmountString } from "@gnu-taler/taler-util";
import { AmlExchangeBackend } from "../utils/types.js";

export default {
  title: "cases",
};

export const OneRow = tests.createExample(TestedComponent, {
  filter: AmlExchangeBackend.AmlState.normal,
  onChangeFilter: () => null,
  records: [{
    current_state: AmlExchangeBackend.AmlState.normal,
    h_payto: "QWEQWEQWEQWE",
    rowid: 1,
    threshold: "USD:1" as AmountString
  }]
});
